@@ -14,13 +14,13 @@ dummy_display = DummyDisplay()
 class TestKeymapNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'data': [236, 252, 232, 206, 210, 131, 246, 234, 162, 151, 217, 167, 171, 128, 239, 200, 179, 146, 209, 131, 223, 155, 181, 171, 175, 220, 227, 200, 138, 134, 148],
-            'type': 207,
+            'data': [248, 202, 136, 187, 201, 200, 244, 146, 187, 195, 178, 236, 157, 185, 166, 196, 164, 146, 143, 170, 206, 201, 240, 159, 247, 205, 231, 197, 254, 240, 148],
+            'type': 138,
             }
-        self.evt_bin_0 = b'\xcf\xec\xfc\xe8' b'\xce\xd2\x83\xf6' \
-            b'\xea\xa2\x97\xd9' b'\xa7\xab\x80\xef' \
-            b'\xc8\xb3\x92\xd1' b'\x83\xdf\x9b\xb5' \
-            b'\xab\xaf\xdc\xe3' b'\xc8\x8a\x86\x94'
+        self.evt_bin_0 = b'\x8a\xf8\xca\x88' b'\xbb\xc9\xc8\xf4' \
+            b'\x92\xbb\xc3\xb2' b'\xec\x9d\xb9\xa6' \
+            b'\xc4\xa4\x92\x8f' b'\xaa\xce\xc9\xf0' \
+            b'\x9f\xf7\xcd\xe7' b'\xc5\xfe\xf0\x94'
 
 
     def testPack0(self):
@@ -36,18 +36,18 @@ class TestKeymapNotify(EndianTest):
 class TestExpose(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'count': 7686,
-            'height': 49538,
-            'sequence_number': 18018,
-            'type': 214,
-            'width': 18088,
-            'window': 1421524673,
-            'x': 31959,
-            'y': 29112,
+            'count': 15258,
+            'height': 6241,
+            'sequence_number': 48394,
+            'type': 238,
+            'width': 1951,
+            'window': 692245859,
+            'x': 39820,
+            'y': 16664,
             }
-        self.evt_bin_0 = b'\xd6\x00\x62\x46' b'\xc1\xbe\xba\x54' \
-            b'\xd7\x7c\xb8\x71' b'\xa8\x46\x82\xc1' \
-            b'\x06\x1e\x00\x00' b'\x00\x00\x00\x00' \
+        self.evt_bin_0 = b'\xee\x00\x0a\xbd' b'\x63\xd5\x42\x29' \
+            b'\x8c\x9b\x18\x41' b'\x9f\x07\x61\x18' \
+            b'\x9a\x3b\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
 
@@ -64,20 +64,20 @@ class TestExpose(EndianTest):
 class TestGraphicsExpose(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'count': 757,
-            'drawable': 1457059207,
-            'height': 26058,
-            'major_event': 166,
-            'minor_event': 39379,
-            'sequence_number': 18746,
-            'type': 183,
-            'width': 3220,
-            'x': 32023,
-            'y': 43806,
+            'count': 49818,
+            'drawable': 1443779242,
+            'height': 2892,
+            'major_event': 172,
+            'minor_event': 50267,
+            'sequence_number': 50375,
+            'type': 133,
+            'width': 38020,
+            'x': 54088,
+            'y': 17918,
             }
-        self.evt_bin_0 = b'\xb7\x00\x3a\x49' b'\x87\xf5\xd8\x56' \
-            b'\x17\x7d\x1e\xab' b'\x94\x0c\xca\x65' \
-            b'\xd3\x99\xf5\x02' b'\xa6\x00\x00\x00' \
+        self.evt_bin_0 = b'\x85\x00\xc7\xc4' b'\xaa\x52\x0e\x56' \
+            b'\x48\xd3\xfe\x45' b'\x84\x94\x4c\x0b' \
+            b'\x5b\xc4\x9a\xc2' b'\xac\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
 
@@ -94,14 +94,14 @@ class TestGraphicsExpose(EndianTest):
 class TestNoExpose(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'major_event': 128,
-            'minor_event': 21675,
-            'sequence_number': 9214,
-            'type': 155,
-            'window': 548772746,
+            'major_event': 199,
+            'minor_event': 29237,
+            'sequence_number': 34266,
+            'type': 248,
+            'window': 1399171519,
             }
-        self.evt_bin_0 = b'\x9b\x00\xfe\x23' b'\x8a\x9b\xb5\x20' \
-            b'\xab\x54\x80\x00' b'\x00\x00\x00\x00' \
+        self.evt_bin_0 = b'\xf8\x00\xda\x85' b'\xbf\xa9\x65\x53' \
+            b'\x35\x72\xc7\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -119,13 +119,13 @@ class TestNoExpose(EndianTest):
 class TestVisibilityNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'sequence_number': 11725,
-            'state': 218,
-            'type': 223,
-            'window': 816529890,
+            'sequence_number': 38616,
+            'state': 253,
+            'type': 174,
+            'window': 936121409,
             }
-        self.evt_bin_0 = b'\xdf\x00\xcd\x2d' b'\xe2\x41\xab\x30' \
-            b'\xda\x00\x00\x00' b'\x00\x00\x00\x00' \
+        self.evt_bin_0 = b'\xae\x00\xd8\x96' b'\x41\x14\xcc\x37' \
+            b'\xfd\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -143,20 +143,20 @@ class TestVisibilityNotify(EndianTest):
 class TestCreateNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'border_width': 56534,
-            'height': 60389,
-            'override': 1,
-            'parent': 1731314417,
-            'sequence_number': 54657,
-            'type': 192,
-            'width': 1479,
-            'window': 154841762,
-            'x': -4750,
-            'y': -31393,
+            'border_width': 56468,
+            'height': 7111,
+            'override': 0,
+            'parent': 747306217,
+            'sequence_number': 31058,
+            'type': 151,
+            'width': 44173,
+            'window': 876986399,
+            'x': -21847,
+            'y': -22248,
             }
-        self.evt_bin_0 = b'\xc0\x00\x81\xd5' b'\xf1\xc2\x31\x67' \
-            b'\xa2\xb2\x3a\x09' b'\x72\xed\x5f\x85' \
-            b'\xc7\x05\xe5\xeb' b'\xd6\xdc\x01\x00' \
+        self.evt_bin_0 = b'\x97\x00\x52\x79' b'\xe9\xfc\x8a\x2c' \
+            b'\x1f\xc0\x45\x34' b'\xa9\xaa\x18\xa9' \
+            b'\x8d\xac\xc7\x1b' b'\x94\xdc\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
 
@@ -173,13 +173,13 @@ class TestCreateNotify(EndianTest):
 class TestDestroyNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'event': 897029110,
-            'sequence_number': 46572,
-            'type': 201,
-            'window': 247390922,
+            'event': 1489718405,
+            'sequence_number': 27233,
+            'type': 212,
+            'window': 1064077163,
             }
-        self.evt_bin_0 = b'\xc9\x00\xec\xb5' b'\xf6\x93\x77\x35' \
-            b'\xca\xe2\xbe\x0e' b'\x00\x00\x00\x00' \
+        self.evt_bin_0 = b'\xd4\x00\x61\x6a' b'\x85\x4c\xcb\x58' \
+            b'\x6b\x87\x6c\x3f' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -197,14 +197,14 @@ class TestDestroyNotify(EndianTest):
 class TestUnmapNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'event': 1720839242,
-            'from_configure': 1,
-            'sequence_number': 21456,
-            'type': 130,
-            'window': 1327438921,
+            'event': 2029853215,
+            'from_configure': 0,
+            'sequence_number': 43679,
+            'type': 201,
+            'window': 860030193,
             }
-        self.evt_bin_0 = b'\x82\x00\xd0\x53' b'\x4a\xec\x91\x66' \
-            b'\x49\x1c\x1f\x4f' b'\x01\x00\x00\x00' \
+        self.evt_bin_0 = b'\xc9\x00\x9f\xaa' b'\x1f\x1a\xfd\x78' \
+            b'\xf1\x04\x43\x33' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -222,14 +222,14 @@ class TestUnmapNotify(EndianTest):
 class TestMapNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'event': 1813526544,
+            'event': 675485985,
             'override': 1,
-            'sequence_number': 6009,
-            'type': 245,
-            'window': 522567740,
+            'sequence_number': 6027,
+            'type': 244,
+            'window': 542087937,
             }
-        self.evt_bin_0 = b'\xf5\x00\x79\x17' b'\x10\x38\x18\x6c' \
-            b'\x3c\xc0\x25\x1f' b'\x01\x00\x00\x00' \
+        self.evt_bin_0 = b'\xf4\x00\x8b\x17' b'\x21\x19\x43\x28' \
+            b'\x01\x9b\x4f\x20' b'\x01\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -247,13 +247,13 @@ class TestMapNotify(EndianTest):
 class TestMapRequest(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'parent': 666354749,
-            'sequence_number': 26091,
-            'type': 195,
-            'window': 729142504,
+            'parent': 1659099581,
+            'sequence_number': 63838,
+            'type': 157,
+            'window': 868024861,
             }
-        self.evt_bin_0 = b'\xc3\x00\xeb\x65' b'\x3d\xc4\xb7\x27' \
-            b'\xe8\xd4\x75\x2b' b'\x00\x00\x00\x00' \
+        self.evt_bin_0 = b'\x9d\x00\x5e\xf9' b'\xbd\xd9\xe3\x62' \
+            b'\x1d\x02\xbd\x33' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -271,18 +271,18 @@ class TestMapRequest(EndianTest):
 class TestReparentNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'event': 1096286586,
-            'override': 1,
-            'parent': 1095145830,
-            'sequence_number': 11231,
-            'type': 170,
-            'window': 244928407,
-            'x': -3314,
-            'y': -21409,
+            'event': 1867017989,
+            'override': 0,
+            'parent': 992152190,
+            'sequence_number': 43356,
+            'type': 128,
+            'window': 1165276406,
+            'x': -19227,
+            'y': -30992,
             }
-        self.evt_bin_0 = b'\xaa\x00\xdf\x2b' b'\x7a\x01\x58\x41' \
-            b'\x97\x4f\x99\x0e' b'\x66\x99\x46\x41' \
-            b'\x0e\xf3\x5f\xac' b'\x01\x00\x00\x00' \
+        self.evt_bin_0 = b'\x80\x00\x5c\xa9' b'\x05\x6f\x48\x6f' \
+            b'\xf6\xb4\x74\x45' b'\x7e\x0a\x23\x3b' \
+            b'\xe5\xb4\xf0\x86' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
 
@@ -299,22 +299,22 @@ class TestReparentNotify(EndianTest):
 class TestConfigureNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'above_sibling': 423690578,
-            'border_width': 50707,
-            'event': 507433541,
-            'height': 11820,
+            'above_sibling': 1343120585,
+            'border_width': 17757,
+            'event': 1624514845,
+            'height': 13596,
             'override': 0,
-            'sequence_number': 53461,
-            'type': 232,
-            'width': 43047,
-            'window': 314542502,
-            'x': -13183,
-            'y': -8052,
+            'sequence_number': 41060,
+            'type': 220,
+            'width': 3638,
+            'window': 1070571314,
+            'x': -18284,
+            'y': -7865,
             }
-        self.evt_bin_0 = b'\xe8\x00\xd5\xd0' b'\x45\xd2\x3e\x1e' \
-            b'\xa6\x89\xbf\x12' b'\x52\x01\x41\x19' \
-            b'\x81\xcc\x8c\xe0' b'\x27\xa8\x2c\x2e' \
-            b'\x13\xc6\x00\x00' b'\x00\x00\x00\x00'
+        self.evt_bin_0 = b'\xdc\x00\x64\xa0' b'\x1d\x21\xd4\x60' \
+            b'\x32\x9f\xcf\x3f' b'\xc9\x64\x0e\x50' \
+            b'\x94\xb8\x47\xe1' b'\x36\x0e\x1c\x35' \
+            b'\x5d\x45\x00\x00' b'\x00\x00\x00\x00'
 
 
     def testPack0(self):
@@ -330,23 +330,23 @@ class TestConfigureNotify(EndianTest):
 class TestConfigureRequest(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'border_width': 4713,
-            'height': 10110,
-            'parent': 1984611127,
-            'sequence_number': 29560,
-            'sibling': 1364316652,
-            'stack_mode': 225,
-            'type': 224,
-            'value_mask': 29123,
-            'width': 41200,
-            'window': 1212265415,
-            'x': -12463,
-            'y': -4669,
+            'border_width': 52639,
+            'height': 40159,
+            'parent': 1499546058,
+            'sequence_number': 57983,
+            'sibling': 260826075,
+            'stack_mode': 240,
+            'type': 201,
+            'value_mask': 15938,
+            'width': 41545,
+            'window': 1040976198,
+            'x': -31823,
+            'y': -880,
             }
-        self.evt_bin_0 = b'\xe0\xe1\x78\x73' b'\x37\xc3\x4a\x76' \
-            b'\xc7\xb3\x41\x48' b'\xec\xd1\x51\x51' \
-            b'\x51\xcf\xc3\xed' b'\xf0\xa0\x7e\x27' \
-            b'\x69\x12\xc3\x71' b'\x00\x00\x00\x00'
+        self.evt_bin_0 = b'\xc9\xf0\x7f\xe2' b'\xca\x41\x61\x59' \
+            b'\x46\x09\x0c\x3e' b'\xdb\xe3\x8b\x0f' \
+            b'\xb1\x83\x90\xfc' b'\x49\xa2\xdf\x9c' \
+            b'\x9f\xcd\x42\x3e' b'\x00\x00\x00\x00'
 
 
     def testPack0(self):
@@ -362,15 +362,15 @@ class TestConfigureRequest(EndianTest):
 class TestGravityNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'event': 120690564,
-            'sequence_number': 18186,
-            'type': 166,
-            'window': 1089529951,
-            'x': -22676,
-            'y': -18075,
+            'event': 1182983311,
+            'sequence_number': 20621,
+            'type': 168,
+            'window': 29431224,
+            'x': -14672,
+            'y': -19399,
             }
-        self.evt_bin_0 = b'\xa6\x00\x0a\x47' b'\x84\x97\x31\x07' \
-            b'\x5f\xe8\xf0\x40' b'\x6c\xa7\x65\xb9' \
+        self.evt_bin_0 = b'\xa8\x00\x8d\x50' b'\x8f\xe4\x82\x46' \
+            b'\xb8\x15\xc1\x01' b'\xb0\xc6\x39\xb4' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -388,14 +388,14 @@ class TestGravityNotify(EndianTest):
 class TestResizeRequest(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'height': 56089,
-            'sequence_number': 54549,
-            'type': 135,
-            'width': 56674,
-            'window': 164839077,
+            'height': 60085,
+            'sequence_number': 14981,
+            'type': 151,
+            'width': 55398,
+            'window': 2130921516,
             }
-        self.evt_bin_0 = b'\x87\x00\x15\xd5' b'\xa5\x3e\xd3\x09' \
-            b'\x62\xdd\x19\xdb' b'\x00\x00\x00\x00' \
+        self.evt_bin_0 = b'\x97\x00\x85\x3a' b'\x2c\x48\x03\x7f' \
+            b'\x66\xd8\xb5\xea' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -413,16 +413,16 @@ class TestResizeRequest(EndianTest):
 class TestPropertyNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'atom': 1190414551,
-            'sequence_number': 33357,
-            'state': 242,
-            'time': 1700429414,
-            'type': 206,
-            'window': 993700932,
+            'atom': 252322161,
+            'sequence_number': 30497,
+            'state': 167,
+            'time': 1391011497,
+            'type': 157,
+            'window': 2033863003,
             }
-        self.evt_bin_0 = b'\xce\x00\x4d\x82' b'\x44\xac\x3a\x3b' \
-            b'\xd7\x48\xf4\x46' b'\x66\x7e\x5a\x65' \
-            b'\xf2\x00\x00\x00' b'\x00\x00\x00\x00' \
+        self.evt_bin_0 = b'\x9d\x00\x21\x77' b'\x5b\x49\x3a\x79' \
+            b'\x71\x21\x0a\x0f' b'\xa9\x26\xe9\x52' \
+            b'\xa7\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
 
@@ -439,14 +439,14 @@ class TestPropertyNotify(EndianTest):
 class TestSelectionClear(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'atom': 1021439924,
-            'sequence_number': 53120,
-            'time': 1399833091,
-            'type': 185,
-            'window': 690517929,
+            'atom': 1092859866,
+            'sequence_number': 61378,
+            'time': 1538959461,
+            'type': 255,
+            'window': 626833463,
             }
-        self.evt_bin_0 = b'\xb9\x00\x80\xcf' b'\x03\xc2\x6f\x53' \
-            b'\xa9\x77\x28\x29' b'\xb4\xef\xe1\x3c' \
+        self.evt_bin_0 = b'\xff\x00\xc2\xef' b'\x65\xa8\xba\x5b' \
+            b'\x37\xb8\x5c\x25' b'\xda\xb7\x23\x41' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -464,19 +464,19 @@ class TestSelectionClear(EndianTest):
 class TestSelectionRequest(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'owner': 1930866783,
-            'property': 370621667,
-            'requestor': 737570035,
-            'selection': 1533999683,
-            'sequence_number': 4295,
-            'target': 1083543199,
-            'time': 222327341,
-            'type': 147,
+            'owner': 1036225485,
+            'property': 981007010,
+            'requestor': 2105124856,
+            'selection': 1014149797,
+            'sequence_number': 27485,
+            'target': 523473665,
+            'time': 1792621552,
+            'type': 197,
             }
-        self.evt_bin_0 = b'\x93\x00\xc7\x10' b'\x2d\x72\x40\x0d' \
-            b'\x5f\xb0\x16\x73' b'\xf3\x6c\xf6\x2b' \
-            b'\x43\xfa\x6e\x5b' b'\x9f\x8e\x95\x40' \
-            b'\xe3\x3c\x17\x16' b'\x00\x00\x00\x00'
+        self.evt_bin_0 = b'\xc5\x00\x5d\x6b' b'\xf0\x3b\xd9\x6a' \
+            b'\xcd\x8b\xc3\x3d' b'\xf8\xa7\x79\x7d' \
+            b'\xa5\xb2\x72\x3c' b'\x01\x93\x33\x1f' \
+            b'\xa2\xfa\x78\x3a' b'\x00\x00\x00\x00'
 
 
     def testPack0(self):
@@ -492,17 +492,17 @@ class TestSelectionRequest(EndianTest):
 class TestSelectionNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'property': 607556330,
-            'requestor': 1122624134,
-            'selection': 340960018,
-            'sequence_number': 28832,
-            'target': 800734635,
-            'time': 943687849,
-            'type': 159,
+            'property': 1602716574,
+            'requestor': 1979762314,
+            'selection': 1287219120,
+            'sequence_number': 25394,
+            'target': 1091504539,
+            'time': 409398186,
+            'type': 165,
             }
-        self.evt_bin_0 = b'\x9f\x00\xa0\x70' b'\xa9\x88\x3f\x38' \
-            b'\x86\xe2\xe9\x42' b'\x12\xa3\x52\x14' \
-            b'\xab\x3d\xba\x2f' b'\xea\x92\x36\x24' \
+        self.evt_bin_0 = b'\xa5\x00\x32\x63' b'\xaa\xeb\x66\x18' \
+            b'\x8a\xc6\x00\x76' b'\xb0\x67\xb9\x4c' \
+            b'\x9b\x09\x0f\x41' b'\x9e\x83\x87\x5f' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
 
@@ -519,15 +519,15 @@ class TestSelectionNotify(EndianTest):
 class TestColormapNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'colormap': 1694865742,
+            'colormap': 593302316,
             'new': 1,
-            'sequence_number': 22344,
-            'state': 136,
-            'type': 180,
-            'window': 1283976465,
+            'sequence_number': 56880,
+            'state': 215,
+            'type': 162,
+            'window': 149981547,
             }
-        self.evt_bin_0 = b'\xb4\x00\x48\x57' b'\x11\xed\x87\x4c' \
-            b'\x4e\x99\x05\x65' b'\x01\x88\x00\x00' \
+        self.evt_bin_0 = b'\xa2\x00\x30\xde' b'\x6b\x89\xf0\x08' \
+            b'\x2c\x13\x5d\x23' b'\x01\xd7\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
 
@@ -545,38 +545,38 @@ class TestColormapNotify(EndianTest):
 class TestClientMessage(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'client_type': 1554224294,
+            'client_type': 607457628,
             'data': (8, b'01234567890123456789'),
-            'sequence_number': 44540,
-            'type': 140,
-            'window': 610247893,
+            'sequence_number': 54031,
+            'type': 196,
+            'window': 5574388,
             }
-        self.evt_bin_0 = b'\x8c\x08\xfc\xad' b'\xd5\xa4\x5f\x24' \
-            b'\xa6\x94\xa3\x5c' b'\x30\x31\x32\x33' \
+        self.evt_bin_0 = b'\xc4\x08\x0f\xd3' b'\xf4\x0e\x55\x00' \
+            b'\x5c\x11\x35\x24' b'\x30\x31\x32\x33' \
             b'\x34\x35\x36\x37' b'\x38\x39\x30\x31' \
             b'\x32\x33\x34\x35' b'\x36\x37\x38\x39'
 
         self.evt_args_1 = {
-            'client_type': 715933209,
+            'client_type': 1245441508,
             'data': (16, [1, 2, 3, 4, 5, 6, 7, 8, 9, 10]),
-            'sequence_number': 59422,
-            'type': 212,
-            'window': 1875362098,
+            'sequence_number': 55140,
+            'type': 204,
+            'window': 1260504694,
             }
-        self.evt_bin_1 = b'\xd4\x10\x1e\xe8' b'\x32\xc1\xc7\x6f' \
-            b'\x19\x46\xac\x2a' b'\x01\x00\x02\x00' \
+        self.evt_bin_1 = b'\xcc\x10\x64\xd7' b'\x76\xc6\x21\x4b' \
+            b'\xe4\xed\x3b\x4a' b'\x01\x00\x02\x00' \
             b'\x03\x00\x04\x00' b'\x05\x00\x06\x00' \
             b'\x07\x00\x08\x00' b'\x09\x00\x0a\x00'
 
         self.evt_args_2 = {
-            'client_type': 2078114542,
+            'client_type': 959018764,
             'data': (32, [1, 2, 3, 4, 5]),
-            'sequence_number': 9488,
-            'type': 202,
-            'window': 751277030,
+            'sequence_number': 56961,
+            'type': 253,
+            'window': 319171761,
             }
-        self.evt_bin_2 = b'\xca\x20\x10\x25' b'\xe6\x93\xc7\x2c' \
-            b'\xee\x82\xdd\x7b' b'\x01\x00\x00\x00' \
+        self.evt_bin_2 = b'\xfd\x20\x81\xde' b'\xb1\x2c\x06\x13' \
+            b'\x0c\x77\x29\x39' b'\x01\x00\x00\x00' \
             b'\x02\x00\x00\x00' b'\x03\x00\x00\x00' \
             b'\x04\x00\x00\x00' b'\x05\x00\x00\x00'
 
@@ -612,13 +612,13 @@ class TestClientMessage(EndianTest):
 class TestMappingNotify(EndianTest):
     def setUp(self):
         self.evt_args_0 = {
-            'count': 167,
-            'first_keycode': 248,
-            'request': 204,
-            'sequence_number': 25843,
-            'type': 217,
+            'count': 244,
+            'first_keycode': 224,
+            'request': 213,
+            'sequence_number': 22874,
+            'type': 251,
             }
-        self.evt_bin_0 = b'\xd9\x00\xf3\x64' b'\xcc\xf8\xa7\x00' \
+        self.evt_bin_0 = b'\xfb\x00\x5a\x59' b'\xd5\xe0\xf4\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00' \
             b'\x00\x00\x00\x00' b'\x00\x00\x00\x00'
